@@ -17,11 +17,11 @@
  *                MdcGetSpmOpt()           - Get specific SPM options      *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-anlz.c,v 1.81 2008/01/23 21:28:35 enlf Exp $
+/* $Id: m-anlz.c,v 1.83 2009/05/14 20:12:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2008 by Erik Nolf
+   Copyright (C) 1997-2009 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -572,7 +572,7 @@ int MdcWriteHeaderKey(FILEINFO *fi)
 int MdcWriteImageDimension(FILEINFO *fi, MDC_SPMOPT *opt)
 {
   MDC_ANLZ_IMAGE_DIMS imd;
-  float glmax, glmin;
+  float glmax=0., glmin=0.;
   int i;
 
   memset(&imd,0,MDC_ANLZ_IMD_SIZE);
