@@ -18,11 +18,11 @@
  *                - Mosaic support     - Roland Marcus Rutschmann          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-dicm.c,v 1.182 2008/01/23 21:28:35 enlf Exp $
+/* $Id: m-dicm.c,v 1.184 2009/05/14 20:12:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2008 by Erik Nolf
+   Copyright (C) 1997-2009 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -1983,12 +1983,13 @@ char *MdcDicomWriteG0054(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 /* write Images */
 char *MdcDicomWriteG7FE0(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
 {
-  Uint32 i, bytes, pixels, len;
-  Uint8 *newbuff, *buff;
+  Uint32 i, bytes, pixels, len, PAD_EVEN=0;
+  Uint8 *newbuff, *buff, c=0x00;
   float slope, intercept;
 
   /* group 0x7FE0 - dump the images */
   bytes = fi->number * fi->mwidth * fi->mheight * MdcType2Bytes(dicom->type);
+  if (bytes%2) { PAD_EVEN=1; bytes+=1; }
   mdc_dicom_write_element(fi->ofp,0x7fe0,0x0010,bytes,(Uint8 *)&dicom->type);
 
   for (i=0; i<fi->number; i++) {
@@ -2019,6 +2020,12 @@ char *MdcDicomWriteG7FE0(FILEINFO *fi, MDC_DICOM_STUFF_T *dicom)
      MdcFree(buff);
   }
 
+  if (PAD_EVEN) {
+    if (fwrite(&c,1,1,fi->ofp) != 1) {
+      return("DICM Failed to pad image");
+    }
+  }
+
   if (MDC_QUANTIFY == MDC_YES || MDC_CALIBRATE == MDC_YES) {
     /* rewrite the true intercept value */
     fseek(fi->ofp,(signed)MDC_REWRF_INTERCEPT,SEEK_SET);
