@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-global.c,v 1.78 2008/01/23 21:28:36 enlf Exp $
+/* $Id: m-global.c,v 1.79 2009/05/14 20:08:57 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2008 by Erik Nolf
+   Copyright (C) 1997-2009 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -152,7 +152,7 @@ Uint32 mdc_crop_width   = 0;
 Uint32 mdc_crop_height  = 0;
 
 /* flags & options */
-char MDC_INSTITUTION[MDC_MAXSTR]="UZGENT"; /* name of institution           */
+char MDC_INSTITUTION[MDC_MAXSTR]="NucMed"; /* name of institution           */
 
 Int8 MDC_COLOR_MODE=  MDC_COLOR_RGB;    /* default color mode               */
 Int8 MDC_COLOR_MAP =  MDC_MAP_GRAY;     /* gray color palette selected      */
