@@ -12,11 +12,11 @@
  *                MdcWriteNIFTI()           - Write NIFTI file             *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-nifti.c,v 1.25 2008/03/06 09:37:59 enlf Exp $
+/* $Id: m-nifti.c,v 1.28 2009/05/14 20:12:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2008 by Erik Nolf
+   Copyright (C) 1997-2009 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -228,9 +228,17 @@ const char *MdcReadNIFTI(FILEINFO *fi)
     nifti_image_free(nim); return("NIFTI Bad malloc IMG_DATA structs");
   }
 
+  /* make sure indices are one-based */
+  if (nim->nw == 0) nim->nw = 1;
+  if (nim->nv == 0) nim->nv = 1;
+  if (nim->nu == 0) nim->nu = 1;
+  if (nim->nt == 0) nim->nt = 1;
+  if (nim->nz == 0) nim->nz = 1;
+
   /* fill in IMG_DATA structs */
   bytes = fi->mwidth * fi->mheight * MdcType2Bytes(fi->type);
   pbuf = (Uint8 *)nim->data;
+  
   i=0; dim[0]=7;
   for (dim[7]=0; dim[7] < nim->nw; dim[7]++ )                     /* nw */
   for (dim[6]=0; dim[6] < nim->nv; dim[6]++ )                     /* nv */
@@ -354,6 +362,13 @@ const char *MdcWriteNIFTI(FILEINFO *fi)
 
   for (i=0; i<8; i++) nim->pixdim[i] = fi->pixdim[i];
 
+#ifdef MDC_USE_SLICE_SPACING
+  if (fi->number > 1) {
+    nim->dz = fi->image[0].slice_spacing;
+    nim->pixdim[3] = nim->dz;
+  }
+#endif
+
   nim->xyz_units = NIFTI_UNITS_MM;
   nim->time_units = NIFTI_UNITS_MSEC;
 
