@@ -21,11 +21,11 @@
  *                MdcContrastRemap()         - Apply contrast remapping    *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-transf.c,v 1.33 2008/03/06 08:17:38 enlf Exp $
+/* $Id: m-transf.c,v 1.35 2009/05/14 20:12:17 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2008 by Erik Nolf
+   Copyright (C) 1997-2009 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -458,7 +458,7 @@ char *MdcContrastRemap(FILEINFO *fi)
   Uint8 *pix;
   Uint32 i, p, n;
   Int16 *newbuf, newtype=BIT16_S, pix16;
-  Int16 max, min, glmax, glmin;
+  Int16 max=0, min=0, glmax=0, glmin=0;
 
   /* handle window centre/width */
   if (MDC_FORCE_CONTRAST == MDC_YES) {
