@@ -15,11 +15,11 @@
  *                XMdcAbout()             - Hello                          *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: xfancy.c,v 1.20 2008/01/23 21:28:37 enlf Exp $
+/* $Id: xfancy.c,v 1.21 2009/05/14 20:08:57 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2008 by Erik Nolf
+   Copyright (C) 1997-2009 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -150,8 +150,7 @@ void XMdcAbout(GtkWidget *widget, gpointer data)
   gtk_widget_show(box1);
 
   sprintf(mdcbufr," %s %s \n\n",MDC_PRGR,MdcGetLibShortVersion());
-  strcat(mdcbufr," Ghent University \n" \
-                 " Hospital \n\n" \
+  strcat(mdcbufr," \n\n" \
                  " http://xmedcon.sourceforge.net \n\n" \
                  " With special regards to You \n\n" \
                  " Licensed  by  Murphy's Law \n" \
